@@ -23,7 +23,7 @@ TODO : Remove global variables where possible
 import os
 import subprocess
 import sys
-import cgi
+import html
 import re
 import time
 import datetime
@@ -38,7 +38,7 @@ from parser import PContext
 from parser import remove_indent
 from parser import *
 
-from urllib import quote
+from urllib.parse import quote
 
 VERSION = ""
 HAPROXY_GIT_VERSION = False
@@ -78,16 +78,16 @@ def main():
 # the documentation
 def get_git_version():
     if not os.path.isdir(".git"):
-        print >> sys.stderr, "This does not appear to be a Git repository."
+        print("This does not appear to be a Git repository.", file=sys.stderr)
         return
     try:
         p = subprocess.Popen(["git", "describe", "--tags", "--match", "v*"], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     except EnvironmentError:
-        print >> sys.stderr, "Unable to run git"
+        print("Unable to run git", file=sys.stderr)
         return
     version = p.communicate()[0]
     if p.returncode != 0:
-        print >> sys.stderr, "Unable to run git"
+        print("Unable to run git", file=sys.stderr)
         return
 
     if len(version) < 2:
@@ -136,7 +136,7 @@ def getTitleDetails(string):
 def createLinks():
     global document, keywords, keywordsCount, keyword_conflicts, chapters
 
-    print >> sys.stderr, "Generating keywords links..."
+    print("Generating keywords links...", file=sys.stderr)
 
     delimiters = [
         dict(start='&quot;', end='&quot;', multi=True ),
@@ -211,7 +211,7 @@ def convert(infile, outfile, base=''):
     hasSummary = False
 
     data = []
-    fd = file(infile,"r")
+    fd = open(infile,"r")
     for line in fd:
         line.replace("\t", " " * 8)
         line = line.rstrip()
@@ -258,7 +258,7 @@ def convert(infile, outfile, base=''):
     pctxt.keywordsCount = keywordsCount
     pctxt.chapters = chapters
 
-    print >> sys.stderr, "Importing %s..." % infile
+    print("Importing %s..." % infile, file=sys.stderr)
 
     nblines = len(data)
     i = j = 0
@@ -282,7 +282,7 @@ def convert(infile, outfile, base=''):
 
         else:
             if len(line) > 80:
-                print >> sys.stderr, "Line `%i' exceeds 80 columns" % (i + 1)
+                print("Line `%i' exceeds 80 columns" % (i + 1), file=sys.stderr)
 
             currentSection["content"] = currentSection["content"] + line + "\n"
             j += 1
@@ -309,7 +309,7 @@ def convert(infile, outfile, base=''):
                 #documentAppend("<a name=\"%s\"></a>" % details["chapter"])
                 fulltitle = details["chapter"] + ". " + title
                 if not details["chapter"] in chapters:
-                    print >> sys.stderr, "Adding '%s' to the summary" % details["title"]
+                    print("Adding '%s' to the summary" % details["title"], file=sys.stderr)
                     chapters[details["chapter"]] = details
                     chapterIndexes = sorted(chapters.keys())
 
@@ -320,7 +320,7 @@ def convert(infile, outfile, base=''):
         title = details["title"]
         content = section["content"].rstrip()
 
-        print >> sys.stderr, "Parsing chapter %s..." % title
+        print("Parsing chapter %s..." % title, file=sys.stderr)
 
         if (title == "Summary") or (title and not hasSummary):
             summaryTemplate = pctxt.templates.get_template('summary.html')
@@ -338,7 +338,7 @@ def convert(infile, outfile, base=''):
             documentAppend('<a class="anchor" id="%s" name="%s"></a>' % (details["chapter"], details["chapter"]))
             if level == 1:
                 documentAppend("<div class=\"page-header\">", False)
-            documentAppend('<h%d id="chapter-%s" data-target="%s"><small><a class="small" href="#%s">%s.</a></small> %s</h%d>' % (level, details["chapter"], details["chapter"], details["chapter"], details["chapter"], cgi.escape(title, True), level))
+            documentAppend('<h%d id="chapter-%s" data-target="%s"><small><a class="small" href="#%s">%s.</a></small> %s</h%d>' % (level, details["chapter"], details["chapter"], details["chapter"], details["chapter"], html.escape(title, True), level))
             if level == 1:
                 documentAppend("</div>", False)
 
@@ -353,7 +353,7 @@ def convert(infile, outfile, base=''):
                 if index < len(chapterIndexes) - 1:
                     documentAppend('<li class="next"><a href="#%s">Next</a></li>' % chapterIndexes[index + 1], False)
                 documentAppend('</ul>', False)
-            content = cgi.escape(content, True)
+            content = html.escape(content, True)
             content = re.sub(r'section ([0-9]+(.[0-9]+)*)', r'<a href="#\1">section \1</a>', content)
 
             pctxt.set_content(content)
@@ -460,7 +460,7 @@ def convert(infile, outfile, base=''):
 
     if not hasSummary:
         summaryTemplate = pctxt.templates.get_template('summary.html')
-        print chapters
+        print(chapters)
         document = summaryTemplate.render(
             pctxt = pctxt,
             chapters = chapters,
@@ -474,7 +474,7 @@ def convert(infile, outfile, base=''):
         keyword_chapters = list(keywords[keyword])
         keyword_chapters.sort()
         if len(keyword_chapters) > 1:
-            print >> sys.stderr, 'Multi section keyword : "%s" in chapters %s' % (keyword, list(keyword_chapters))
+            print('Multi section keyword : "%s" in chapters %s' % (keyword, list(keyword_chapters)), file=sys.stderr)
             keyword_conflicts[keyword] = keyword_chapters
 
     keywords = list(keywords)
@@ -492,7 +492,7 @@ def convert(infile, outfile, base=''):
             offset += 1
         keywords.remove(keyword)
 
-    print >> sys.stderr, "Exporting to %s..." % outfile
+    print("Exporting to %s..." % outfile, file=sys.stderr)
 
     template = pctxt.templates.get_template('template.html')
     try:
@@ -514,7 +514,7 @@ def convert(infile, outfile, base=''):
 
     fd = open(outfile,'w')
 
-    print >> fd, template.render(
+    print(template.render(
             pctxt = pctxt,
             headers = pctxt.context['headers'],
             base = base,
@@ -527,7 +527,7 @@ def convert(infile, outfile, base=''):
             version = VERSION,
             date = datetime.datetime.now().strftime("%Y/%m/%d"),
             footer = footer
-    )
+    ), file=fd)
     fd.close()
 
 if __name__ == '__main__':
